@@ -212,9 +212,9 @@ This module also defines an exception 'error'.
 __all__ = ["compile", "escape", "findall", "finditer", "match", "purge",
   "search", "split", "splititer", "sub", "subn", "template", "A", "ASCII", "B",
   "BESTMATCH", "D", "DEBUG", "S", "DOTALL", "F", "FULLCASE", "I", "IGNORECASE",
-  "L", "LOCALE", "M", "MULTILINE", "N", "NEW", "R", "REVERSE", "T", "TEMPLATE",
-  "U", "UNICODE", "V0", "VERSION0", "V1", "VERSION1", "X", "VERBOSE", "W",
-  "WORD", "error"]
+  "L", "LOCALE", "M", "MULTILINE", "R", "REVERSE", "T", "TEMPLATE", "U",
+  "UNICODE", "V0", "VERSION0", "V1", "VERSION1", "X", "VERBOSE", "W", "WORD",
+  "error"]
 
 __version__ = "2.4.0"
 
@@ -515,8 +515,9 @@ def _compile(pattern, flags=0, kwargs=None):
 def compile_replacement(pattern, template):
     "Compiles a replacement template."
     # This function is called by the _regex module.
+    is_unicode = isinstance(template, unicode)
     source = Source(template)
-    if isinstance(template, unicode):
+    if is_unicode:
         def make_string(char_codes):
             return u"".join(unichr(c) for c in char_codes)
     else:
@@ -533,7 +534,7 @@ def compile_replacement(pattern, template):
             # 'compile_repl_escape' will return either an int group reference
             # or a string literal. It returns items (plural) in order to handle
             # a 2-character literal (an invalid escape sequence).
-            is_group, items = compile_repl_escape(source, pattern)
+            is_group, items = compile_repl_escape(source, pattern, is_unicode)
             if is_group:
                 # It's a group, so first flush the literal.
                 if literal:
@@ -553,6 +554,10 @@ def compile_replacement(pattern, template):
 # We define pattern_type here after all the support objects have been defined.
 pattern_type = type(_compile("", 0, {}))
 
+# We'll define an alias for the 'compile' function so that the repr of a
+# pattern object is eval-able.
+Regex = compile
+
 # Register myself for pickling.
 import copy_reg
 
